@@ -16,6 +16,7 @@ use tower_http::trace::TraceLayer;
 use super::handlers;
 use crate::{
     handlers::{ErrorResponseStatus, RespExt},
+    metrics,
     settings::Settings,
 };
 use atuin_server_database::{models::User, Database, DbError};
@@ -81,7 +82,7 @@ async fn teapot() -> impl IntoResponse {
 async fn clacks_overhead<B>(request: Request<B>, next: Next<B>) -> Response {
     let mut response = next.run(request).await;
 
-    let gnu_terry_value = "GNU Terry Pratchett";
+    let gnu_terry_value = "GNU Terry Pratchett, Kris Nova";
     let gnu_terry_header = "X-Clacks-Overhead";
 
     response
@@ -124,6 +125,7 @@ pub fn router<DB: Database>(database: DB, settings: Settings<DB::Settings>) -> R
     .layer(
         ServiceBuilder::new()
             .layer(axum::middleware::from_fn(clacks_overhead))
-            .layer(TraceLayer::new_for_http()),
+            .layer(TraceLayer::new_for_http())
+            .layer(axum::middleware::from_fn(metrics::track_metrics)),
     )
 }
